@@ -1,4 +1,4 @@
-/* $Id: dict.c,v 1.10 2000/05/21 23:59:35 kmaraas Exp $ */
+/* $Id: dict.c,v 1.11 2000/10/18 23:33:33 rbrady Exp $ */
 /* -*- mode: c; style: k&r; c-basic-offset: 4 -*- */
 
 /*
@@ -913,6 +913,9 @@ void dict_command_destroy (dict_command_t *command)
 {
     dict_res_t *res;
     
+    if (!command)
+    	return;
+
     /* Make sure it has disconnected from server */
     dict_command_done (command);
     
