@@ -1,4 +1,4 @@
-/* $Id: gdict-pref-dialog.c,v 1.5 2000/05/21 23:59:35 kmaraas Exp $ */
+/* $Id: gdict-pref-dialog.c,v 1.6 2000/12/22 16:36:32 hovinen Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -567,17 +567,21 @@ pref_dialog_update_pref (GDictPrefDialog *pref_dialog, gboolean save_prefs) {
     smart = gtk_toggle_button_get_active
 	(GTK_TOGGLE_BUTTON (pref_dialog->smart_lookup_btn));
     
-    if (strcmp (gdict_pref.server, server) || gdict_pref.port != atoi (port)) {
+    if (strcmp (gdict_pref.server, server) || 
+		gdict_pref.port != atoi (port) ||
+		gdict_pref.smart != smart) {
+
         old_server = gdict_pref.server; old_port = gdict_pref.port;
         gdict_pref.server = g_strdup(server);
         gdict_pref.port = atoi(port);
         
         /* Try connecting. If we fail, restore the old config and abort */
         if (gdict_init_context ()) {
-	    gnome_error_dialog_parented (_("The server you specified could not be found."), 
-					 GTK_WINDOW (gdict_app));
-	    return -1;
-	}
+			gnome_error_dialog_parented (
+				_("The server you specified could not be found."), 
+				GTK_WINDOW (gdict_app));
+			return -1;
+		}
         
         pref_dialog->context = context;
         
