@@ -1,4 +1,4 @@
-/* $Id: main.c,v 1.15 2000/05/18 00:33:34 hovinen Exp $ */
+/* $Id: main.c,v 1.16 2000/12/22 16:36:32 hovinen Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -55,6 +55,7 @@ static gint save_yourself_cb (GnomeClient       *client,
 int main (int argc, char *argv[])
 {
     gint i;
+	GDictApplet * applet = NULL;
 
     static struct poptOption args[] = {
         {"noapplet", 'a', POPT_ARG_NONE, 0, 0, "Startup without applet support", NULL},
@@ -94,7 +95,7 @@ int main (int argc, char *argv[])
     defbox->context = context;
 
     if (gdict_applet_toggle)
-        gdict_applet_create();
+        applet = gdict_applet_create();
 
     if (!gdict_applet_toggle)
         for (i = 1;  i < argc;  i++)
@@ -108,6 +109,7 @@ int main (int argc, char *argv[])
         gtk_main();
     } else {
         applet_widget_gtk_main();
+		gdict_applet_delete(applet);
     }
 
     gdict_pref_save();
