@@ -1,5 +1,5 @@
 /* -*- Mode: C -*-
- * $Id: gdiskfree_menus.c,v 1.2 2000/04/08 15:49:01 gregm Exp $
+ * $Id: gdiskfree_menus.c,v 1.3 2000/11/08 01:50:10 menesis Exp $
  *
  * GDiskFree -- A disk free space toy (df on steriods).
  * Copyright 1998,1999 Gregory McLean
@@ -42,9 +42,7 @@ static GnomeUIInfo file_menu [] = {
   GNOMEUIINFO_END
 };
 static GnomeUIInfo settings_menu [] = {
-  GNOMEUIINFO_ITEM_STOCK (N_("Properties"),
-			  N_("This sets the overall application settings."),
-			  properties_cb, GNOME_STOCK_MENU_PREF),
+  GNOMEUIINFO_MENU_PREFERENCES_ITEM(properties_cb, NULL),
   GNOMEUIINFO_END
 };
 static GnomeUIInfo help_menu [] = {
