@@ -202,8 +202,6 @@ mdi_color_generic_create_view (MDIColorGeneric *child)
   int type;
   views_t *views;
   
-  printf ("Create view ...\n");
-
   vbox = gtk_vbox_new (FALSE, 0);
 
   /* Create control */
@@ -268,7 +266,7 @@ mdi_color_generic_create_view (MDIColorGeneric *child)
   gtk_signal_connect_object (GTK_OBJECT (vbox), "destroy",
 			     GTK_SIGNAL_FUNC (gtk_object_destroy), 
 			     GTK_OBJECT (view));
-printf ("Ok\n");
+
   return vbox;
 }
 
@@ -412,8 +410,6 @@ mdi_color_generic_dispatch_changes (MDIColorGeneric *mcg)
   ViewColorGeneric *view;
   GList *list;
   
-  printf ("Dispatch ...\n");
-
   if (!mcg->changes) return;
   list = GNOME_MDI_CHILD (mcg)->views;
   while (list) {
@@ -553,20 +549,23 @@ mdi_color_generic_clear (MDIColorGeneric *mcg)
 static void
 remove_col (MDIColorGeneric *mcg, MDIColor *col)
 {
-  if (! col->list->next) { /* Remove last */
-    if (! col->list->prev) { /* Remove last & list->length = 1 */
-      g_list_free (mcg->col);
-      mcg->last_col = mcg->col = NULL;
-    } else { /* Remove last & list->length > 1 */
-      mcg->last_col = col->list->prev;
-      g_list_remove (col->list, col);
-    }
-  } else { /* list->length > 1 */
-    if (! col->list->prev) {/* Remove first & list->length > 1*/
-      mcg->col = g_list_remove (mcg->col, col);
-    } else /* Not first, not last */ {
-      g_list_remove (col->list, col);    
+  if (col->list != NULL) {
+    if (! col->list->next) { /* Remove last */
+      if (! col->list->prev) { /* Remove last & list->length = 1 */
+        g_list_free (mcg->col);
+        mcg->last_col = mcg->col = NULL;
+      } else { /* Remove last & list->length > 1 */
+        mcg->last_col = col->list->prev;
+        g_list_remove (col->list, col);
+      }
+    } else { /* list->length > 1 */
+      if (! col->list->prev) {/* Remove first & list->length > 1*/
+        mcg->col = g_list_remove (mcg->col, col);
+      } else /* Not first, not last */ {
+        g_list_remove (col->list, col);    
+      }
     }
+    col->list = NULL;
   }
 }
 
